@@ -1,16 +1,16 @@
 import asyncpg
-from pydantic.main import BaseModel
+from pydantic import BaseModel
 
 
 class Connection(BaseModel):
-    dbname: str
+    database: str
     user: str
     password: str
     host: str = 'localhost'
-    port: int = 5439
+    port: int = 5432
 
     async def connect(self) -> asyncpg.connection.Connection:
-        return await asyncpg.connect(database=self.dbname,
+        return await asyncpg.connect(database=self.database,
                                      user=self.user,
                                      password=self.password,
                                      host=self.host,
